package com.book.server.service.impl;

import com.book.server.common.entity.PageResult;
import com.book.server.dao.entity.Book;
import com.book.server.dao.entity.example.BookExample;
import com.book.server.dao.mapper.BookMapper;
import com.book.server.model.VO.QueryVO;
import com.book.server.service.BookService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class BookServiceImpl implements BookService {
    @Autowired
    private BookMapper bookMapper;

    @Override
    public PageResult<Book> query(QueryVO queryVO) {
        BookExample example = BookExample.newAndCreateCriteria().example();
        example.or().andNameLike("%" + queryVO.getQuery() + "%");
        example.or().andAuthorLike("%" + queryVO.getQuery() + "%");
        long count = bookMapper.countByExample(example);
        if (count <= 0) {
            return new PageResult<>(queryVO.getPage(), queryVO.getSize(), 0L, null);
        }
        example.page(queryVO.getPage(), queryVO.getSize());
        List<Book> books = bookMapper.selectByExample(example);
        return new PageResult<>(queryVO.getPage(), queryVO.getSize(), count, books);
    }

    @Override
    public PageResult<Book> recommendByRead(QueryVO queryVO) {
        BookExample example = BookExample.newAndCreateCriteria()
                .andSexEqualTo(queryVO.getSex())
                .example();
        long count = bookMapper.countByExample(example);
        example.orderBy(Book.Column.readNum.desc());
        example.page(queryVO.getPage(), queryVO.getSize());
        List<Book> books = bookMapper.selectByExample(example);
        return new PageResult<>(queryVO.getPage(), queryVO.getSize(), count, books);
    }
}
